@ECHO OFF

SETLOCAL EnableDelayedExpansion

REM Modify the following 6 variables according to your environment
set x64arch="x64Win64VS2013"
set x64dlltool="C:\mingw-w64\x86_64-5.3.0-win32-sjlj-rt_v4-rev0\mingw64\bin\dlltool.exe"
set x64gcc="C:\mingw-w64\x86_64-5.3.0-win32-sjlj-rt_v4-rev0\mingw64\bin\gcc.exe"

set i86arch="i86Win32VS2013"
set i86dlltool="c:\mingw-w64\i686-5.3.0-win32-dwarf-rt_v4-rev0\mingw32\bin\dlltool.exe"
set i86gcc="C:\mingw-w64\i686-5.3.0-win32-dwarf-rt_v4-rev0\mingw32\bin\gcc.exe"
REM ###########

IF NOT EXIST "%NDDSHOME%" (
    ECHO Environment variable NDDSHOME is not set. Cannot continue executing.
    exit /b 1    
)

IF "%1"=="" (
    goto :wrong_parameters
)
IF "%1"=="x64" (
    set arch=%x64arch%
        
    IF NOT EXIST ".\64bits" (
        mkdir 64bits
    )
    set outputDir="64bits"

    set dlltool=%x64dlltool%
    set gcc=%x64gcc%
    
    goto :generateprogram   
)
IF "%1"=="i86" (
    set arch=%i86arch%
    
    IF NOT EXIST ".\32bits" (
        mkdir 32bits
    )
    set outputDir="32bits"
    
    set dlltool=%i86dlltool%
    set gcc=%i86gcc%

    goto :generateprogram   
)
       
:wrong_parameters
ECHO Incorrect parameter. Pass i86 to compile 32bits application or x64 to compile 64bits application. No application was generated.
exit /b 1

:generateprogram

set /p generate=Do you want to generate code (files generated previously will be overwritten) (y/n)?
IF NOT "%generate%"=="y" (
    goto :compileprogram
)
   
ECHO. 
ECHO rtiddsgen -example %arch% -language C -replace  -d %outputDir% HelloWorld.idl
call rtiddsgen -example %arch% -language C -replace -d %outputDir% HelloWorld.idl

:compileprogram

ECHO. 
ECHO %dlltool% -k -d nddsc.def -l %outputDir%\libnddsc.a 
call %dlltool% -k -d nddsc.def -l %outputDir%\libnddsc.a 

ECHO. 
ECHO %dlltool% -k -d nddsc.def -l %outputDir%\libnddscore.a
call %dlltool% -k -d nddscore.def -l %outputDir%\libnddscore.a


cd %outputDir%

ECHO.
ECHO copy /Y "%NDDSHOME%\lib\%arch%\nddsc.lib" .\libnddsc.lib
copy /Y "%NDDSHOME%\lib\%arch%\nddsc.lib" .\libnddsc.lib
ECHO copy /Y "%NDDSHOME%\lib\%arch%\nddsc.lib" .\libnddsc.lib
copy /Y "%NDDSHOME%\lib\%arch%\nddscore.lib" .\libnddscore.lib
ECHO copy /Y "%NDDSHOME%\lib\%arch%\nddsc.dll" .\
copy /Y "%NDDSHOME%\lib\%arch%\nddsc.dll" .\
ECHO copy /Y "%NDDSHOME%\lib\%arch%\nddsc.dll" .\
copy /Y "%NDDSHOME%\lib\%arch%\nddscore.dll" .\

ECHO.
ECHO About to start compilation.
ECHO "Ensure that you have modified your <NDDSHOME>\include\ndds\log\log_dll.h if needed."
ECHO "Modify generated files HelloWorld.c and HelloWorld.h to include #include <stdio.h> so compiler can find type __int64."
set /p DUMMY=Hit ENTER to continue when ready...

ECHO.
ECHO %gcc% -I "%NDDSHOME%\include" -I "%NDDSHOME%\include\ndds" -I .\ -DRTI_WIN32 -DNDDS_DLL_VARIABLE -L .\ HelloWorld.c HelloWorld_publisher.c HelloWorldPlugin.c HelloWorldSupport.c -lnddsc -lnddscore -llibnddsc -llibnddscore -o HelloWorld_publisher.exe
call "%gcc%" -I "%NDDSHOME%\include" -I "%NDDSHOME%\include\ndds" -I .\ -DRTI_WIN32 -DNDDS_DLL_VARIABLE -L .\ HelloWorld.c HelloWorld_publisher.c HelloWorldPlugin.c HelloWorldSupport.c -lnddsc -lnddscore -llibnddsc -llibnddscore -o HelloWorld_publisher.exe 

ECHO.
ECHO %gcc% -I "%NDDSHOME%\include" -I "%NDDSHOME%\include\ndds" -I .\ -DRTI_WIN32 -DNDDS_DLL_VARIABLE -L .\ HelloWorld.c HelloWorld_subscriber.c HelloWorldPlugin.c HelloWorldSupport.c -lnddsc -lnddscore -llibnddsc -llibnddscore -o HelloWorld_subscriber.exe
call "%gcc%" -I "%NDDSHOME%\include" -I "%NDDSHOME%\include\ndds" -I .\ -DRTI_WIN32 -DNDDS_DLL_VARIABLE -L .\ HelloWorld.c HelloWorld_subscriber.c HelloWorldPlugin.c HelloWorldSupport.c -lnddsc -lnddscore -llibnddsc -llibnddscore -o HelloWorld_subscriber.exe 

ECHO.
set /p startprogram=Do you want to run the publisher and subscriber (y/n)?
IF "%startprogram%"=="y" (
    start "Subscriber" ".\HelloWorld_subscriber.exe" "58"
	sleep 1
	start "Publisher" ".\HelloWorld_publisher.exe" "58"
)
ECHO.

cd ..

